@@ -49,11 +49,6 @@
 //!                     Agent_2.collect()
 //!                                 Agent_3.collect() ]
 //! */
-//! An Agent needs to have the following fields:
-//!     -
-//!
-//! An Environment needs to have the following fields: 
-//!     - population
 
 
 pub trait Agent {
@@ -77,34 +72,4 @@ pub trait Environment {
 
     ///
     fn tick(&mut self) -> Result<(), &'static str>;
-}
-
-/// A default struct that is used in the default functions.
-pub struct DefaultEnvironment {
-    population: Vec<Box<dyn Agent>>
-}
-
-
-impl Environment for DefaultEnvironment {
-    fn generate(population: Vec<Box<dyn Agent>>) -> Result<Box<Self>, &'static str> {
-        Ok(Box::new(Self {population}))
-    }
-
-    fn collect(&self) -> Result<(), &'static str> {
-        for agent in &self.population {
-            (*agent).collect()?;
-        }
-        Ok(())
-    }
-
-    fn tick(&mut self) -> Result<(), &'static str> {
-        let mut pop: Vec<Box<dyn Agent>> = vec!();
-        for _ in 0..self.population.len() {
-            let mut agent: Box<dyn Agent> = self.population.pop().unwrap();
-            agent.tick()?;
-            pop.push(agent);
-        }
-        self.population = pop;
-        Ok(())
-    }
 }
\ No newline at end of file
